sccoda.util.cell\_composition\_data
===================================

.. automodule:: sccoda.util.cell_composition_data

   
   
   .. rubric:: Functions

   .. autosummary::
   
      from_pandas
      from_scanpy
      from_scanpy_dir
      from_scanpy_list
   
   

   
   
   

   
   
   